@@ -91,39 +91,3 @@ class FeatureVectorFlow(object):
             batch_size=batch_size
         )
         return self.session.post(json=d)
-
-
-def download_virtual_entry(entry, base_folder):
-    """
-
-    :param rebotics_sdk.advanced.packers.VirtualClassificationEntry entry:
-    :param base_folder:
-    :return:
-    """
-    up = urlparse(entry.image_url)
-    remote_loaders.download(
-        entry.image_url,
-        destination=base_folder / "{}{}".format(entry.index, Path(up.path).suffix)
-    )
-
-
-def unload_packer_file(packer, target):
-    with open(target / 'labels.txt', 'w') as labels, open(target / 'features.txt', 'w') as features:
-        for entry in packer.unpack():
-            labels.write("{}\n".format(entry.label))
-            features.write("{}\n".format(entry.feature))
-            yield entry
-
-
-def download_vrcdb_file(packer, target, concurrency=4):
-    target = Path(target)
-    target.mkdir(parents=True, exist_ok=True)
-    images_folder = target / "images"
-    images_folder.mkdir(parents=True, exist_ok=True)
-
-    with Pool(concurrency) as pool:
-        result = pool.imap_unordered(
-            partial(download_virtual_entry, base_folder=images_folder),
-            unload_packer_file(packer, target)
-        )
-    return result
