@@ -165,6 +165,12 @@ class AdminProvider(ReboticsBaseProvider):
             'yaml_template': yaml_template,
         })
 
+    @remote_service('/core/refresh_url/')
+    def refresh_url(self, url):
+        return self.session.post(json={
+            'url': url,
+        })
+
     @remote_service('/core-test/cases/{id}/')
     def get_core_test_case(self, id_):
         return self.session.get(id=id_)
